Hooks:PostHook( WeaponFactoryTweakData, "init", "ThisFileEditsAttachmentStats", function(self)  --replace "ThisFileEditsAttachmentStats" with the name of this file

--[[

weapon mod ids can be found either at https://payday.fandom.com/wiki/Weapons_(Payday_2) on the specific weapons' sites or on https://wiki.modworkshop.net/books/payday-2/page/weapon-mods in a big list all together.

replace the entire "weapon mod id here" bit so that only the weapon id is between the dots (for example "self.parts.wpn_fps_upg_ns_ass_smg_stubby.stats")

]]

self.parts.weapon mod id here.stats = {
	damage = x, 
	spread = x, 
	recoil = x, 
	concealment = x, 
	suppression = x, 
	alert_size = x, 
	reload = x, 
	zoom = x
}

--[[

the stats that the given weapon mod adds to the weapon. value in place of x will be added on top of the gun's default stats. if you don't want a mod to modify a stat, remove it from the line. 

remember to keep them separated by a comma and a space. unlike in gun-stats.lua, leaving a stat unchanged will result in that stat not being changed by the mod instead of being kept as vanilla (for example, if a mod adds 2 concealment, but you change it here to only have "spread = 1", it will now only add 4 accuracy, without the concealment bonus. If you want to keep the vanilla concealment bonus, you need to include both, for example, "spread = 1, concealment = 2")

if you want to add to the value, don't add any prefix (recoil = 1 will add 4 stability). if you want to subtract from the value, add a minus (recoil = -1 will subtract 4 stability).

spread and recoil get multiplied by 4, so spread = 1 will add 4 accuracy to the mod or recoil = -1 will deduct 4 stability from the mod

for the reload stat, the max values are 10 and -10. positive values reduce the reload time (10 reduces it by 50%, 5 by 33%), negative values increase the reload time (-10 increases it by 100%, -5 by 33%).

the zoom stat is used to govern how much your view zooms in when aiming down sights with a given weapon mod equipped (duh). It goes from 0 (iron sights) to 10 (Theia and A5 scope). 

remember that lower suppression and alert_size values mean higher threat and alert radius. if you want to lower these stats, you need to add to the value (suppression = 1 will lower the threat stat), and if you want to increase them, you need to subtract from that value (alert_size = -1 will increase the distance on which the gun is audible). distance table for alert_size is located below. 

donald's horizontal leveller uses a unique stat to cause it's effect of levelling the spread horizontally - spread_multi = {2.25, 0.5}. I don't know how and if it works with other weapons, but I decided to include it anyway for you to experiment with, and in case you wanted to edit the leveller's other stats while preserving its unique effect.

]]

self.parts.weapon mod id here.override_weapon = {
	CLIP_AMMO_MAX = x,
	AMMO_MAX = x,
	AMMO_PICKUP = {minimum pickup, maximum pickup},
	can_shoot_through_enemy = x, --true or false
	can_shoot_through_wall = x, --true or false
	can_shoot_through_shield = x, --true or false
	armor_piercing_chance = x, --1 for always piercing, 0 for no piercing. can be any value inbetween for a chance of piercing.
	fire_mode_data = {fire_rate = 60 / desired fire rate}
}
--use of override_weapon requires WeaponLib. This allows you to directly overwrite the given stat of a weapon (for example, if a gun has 60 total ammo, and you write AMMO_MAX = 30, the given mod will change the weapon's total ammo to 30)

self.parts.weapon mod id here.override_weapon_add = {
	CLIP_AMMO_MAX = x,
	AMMO_MAX = x,
	AMMO_PICKUP = {minimum pickup, maximum pickup}
}
--use of override_weapon_add requires WeaponLib. This allows you to add a value to a gun's existing stat (for example, if a gun has 60 total ammo, and you write AMMO_MAX = 30, the given mod will change the weapon's total ammo to 90)

self.parts.weapon mod id here.override_weapon_multiply = {
	CLIP_AMMO_MAX = x,
	AMMO_MAX = x,
	AMMO_PICKUP = {minimum pickup, maximum pickup},
	fire_mode_data = {fire_rate = 1 / desired fire rate multiplier}
}
--[[

use of override_weapon_multiply requires WeaponLib. This allows you to multiply a gun's existing stat value (for example, if a gun has 60 total ammo, and you write AMMO_MAX = 2, the given mod will change the weapon's total ammo to 120)

AMMO_PICKUP has two values within the brackets - minimum and maximum. Payday 2 randomizes a value between these two whenever you pick up an ammo box.

remember to add a comma (,) after each line except for the last one

override_weapon is separate from stats, meaning that if you don't change anything there, the vanilla stats of a weapon mod will appear alongside the ones you put in override_weapon (for example, if a weapon mod add 4 accuracy, and using override_weapon you'll change it to add 5 mag size, in the game it will add both 4 accuracy and 5 mag size.) to prevent this, simply leave an empty bracket in stats

also, only use one per weapon mod

]]

--Advanced stuff

self.parts.weapon mod id here.forbids = {"weapon mod id here", "weapon mod id here"} --this allows you to set one attachment as incompatible with different one(s). remember to divide them properly, with a ", ", and to put the id of the mod in quotes.

self.full weapon id.override.mod id = {stats = {damage = x, spread = x, recoil = x, concealment = x, suppression = x, alert_size = x, reload = x}} --override allows you to give different stats for the same mod on a different weapon (for example, DMR kits on the CAR and AK rifles adding different amounts of damage). full weapon id is the id that includes the class of the weapon (so for example "wpn_fps_ass_m16" instead of just "m16". These can be found in the "Factory ID" tab on https://wiki.modworkshop.net/books/payday-2/page/weapon-mods 

--other than that, this works as the normal stats above.

table.insert(self.full weapon id.uses_parts, "weapon mod id here") --this allows you to make weapon mods from different weapons availible for the weapon you put in here. Do keep in mind that different weapon mods are aligned differently on different weapons, and might not end up where you might think it would. When that happens, you will have to use Custom Attachment Points to move it. Also, only use one of these per weapon mod. If you want to add multiple mods to one weapon, you need to copy the line and add the other mod in it.

--legacy custom stats

self.parts.weapon mod id here.custom_stats = {ammo_pickup_max_mul = x, ammo_pickup_min_mul = x}

--custom stats is the old way of changing ammo pickup with a weapon mod that doesn't require weaponlib. using this disables any skill-related ammo pickup boosts, resulting in ammo pickup that may seem far lower than it should be. most notably, custom stats are used by the dmr kits for the ak and ar family. if you wish to rebalance them, you must remember to remove these multipliers by leaving an empty bracket (remove both ammo pickup multipliers), otherwise ammo pickup changes done with override_weapon won't apply properly. alternatively, you can use this as a weaponlib free alternative to change ammo pickup on weapons.

self.full weapon id.override.mod id = {custom_stats = {ammo_pickup_max_mul = x, ammo_pickup_min_mul = x}}

--same thing as above, except override. this is once again the fault of DMR kits, being mods that are used by two different weapons and thus needing two different sets of stats, including ammo pickup changes.

--[[

override_weapon (not to be confused with the override above) and it's _add and _mult variants all require WeaponLib in order to work. For more info on how they work, visit https://gitlab.com/cpone/WeaponLib/-/wikis/Weapon-Tweak-Data-Override

the three variations of override_weapon can be used to modify pretty much any stat (and even other properties of a weapon that aren't stats). however, due to the fact that mag size, total ammo, pickup, rate of fire and piercing capability were previously implemented using very janky methods, i decided to only implement those using this method for the time being. maybe with time I will move other stats to use this method too, but it will require a bit of testing from me. so for now, if you wish to use override_weapon for different stats than the one listed in this template, you will have to do so without my guidance.

distance table for the alert_size stat:
1 = 300 meters
2 = 200m
3 = 150m
4 = 100m
5 = 75m
6 = 60m
7 = 45m
8 = 40m
9 = 35m
10 = 18m
11 = 15m
12 = 12m
13 = 10m
14 = 8.5m
15 = 7m
16 = 5m
17 = 3.5m
18 = 2m
19 = 1m
20 = 0m

]]

end ) --DO NOT REMOVE THIS LINE